Module encounters

Module encounters 

Encounters endpoints group

Modules

encounter_condition
Conditions which affect what pokemon might appear in the wild, e.g., day or night.
encounter_condition_value
Encounter condition values are the various states that an encounter condition can have, i.e., time of day can be either day or night.
encounter_method
Methods by which the player might can encounter Pokémon in the wild, e.g., walking in tall grass. Check out Bulbapedia for greater detail.