Module encounter_condition_value

Module encounter_condition_value 

Encounter condition values are the various states that an encounter condition can have, i.e., time of day can be either day or night.

Functions

get_all_entries
Returns all entries from the given resource.
get_by_id
Returns the resource, using its id.
get_by_name
Returns the resource, using its name.
get_page
Returns the default page regarding the resource.
get_page_with_param
Returns the page targeted by the parameters.