Module rustemon::games::generation
source · [−]Expand description
A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include. In each generation, a new set of Pokémon, Moves, Abilities and Types that did not exist in the previous generation are released.
Functions
Returns the resource, using its id.
Returns the resource, using its name.
Returns the default page regarding the resource.
Returns the page targeted by the parameters.