Module rustemon::locations::location_area
source · [−]Expand description
Location areas are sections of areas, such as floors in a building or cave. Each area has its own set of possible Pokémon encounters.
Functions
Returns the resource, using its id.
Returns the resource, using its name.
Returns the default page regarding the resource.
Returns the page targeted by the parameters.