pub struct EvolutionDetail {
Show 18 fields pub item: Option<NamedApiResource<Item>>, pub trigger: Option<NamedApiResource<EvolutionTrigger>>, pub gender: Option<i64>, pub held_item: Option<NamedApiResource<Item>>, pub known_move: Option<NamedApiResource<Move>>, pub known_move_type: Option<NamedApiResource<Type>>, pub location: Option<NamedApiResource<Location>>, pub min_level: Option<i64>, pub min_happiness: Option<i64>, pub min_beauty: Option<i64>, pub min_affection: Option<i64>, pub needs_overworld_rain: Option<bool>, pub party_species: Option<NamedApiResource<PokemonSpecies>>, pub party_type: Option<NamedApiResource<Type>>, pub relative_physical_stats: Option<i64>, pub time_of_day: Option<String>, pub trade_species: Option<NamedApiResource<PokemonSpecies>>, pub turn_upside_down: Option<bool>,
}
Fields

item: Option<NamedApiResource<Item>>

The item required to cause evolution this into Pokémon species.

trigger: Option<NamedApiResource<EvolutionTrigger>>

The type of event that triggers evolution into this Pokémon species.

gender: Option<i64>

The id of the gender of the evolving Pokémon species must be in order to evolve into this Pokémon species.

held_item: Option<NamedApiResource<Item>>

The item the evolving Pokémon species must be holding during the evolution trigger event to evolve into this Pokémon species.

known_move: Option<NamedApiResource<Move>>

The move that must be known by the evolving Pokémon species during the evolution trigger event in order to evolve into this Pokémon species.

known_move_type: Option<NamedApiResource<Type>>

The evolving Pokémon species must know a move with this type during the evolution trigger event in order to evolve into this Pokémon species.

location: Option<NamedApiResource<Location>>

The location the evolution must be triggered at.

min_level: Option<i64>

The minimum required level of the evolving Pokémon species to evolve into this Pokémon species.

min_happiness: Option<i64>

The minimum required level of happiness the evolving Pokémon species to evolve into this Pokémon species.

min_beauty: Option<i64>

The minimum required level of beauty the evolving Pokémon species to evolve into this Pokémon species.

min_affection: Option<i64>

The minimum required level of affection the evolving Pokémon species to evolve into this Pokémon species.

needs_overworld_rain: Option<bool>

Whether or not it must be raining in the overworld to cause evolution this Pokémon species.

party_species: Option<NamedApiResource<PokemonSpecies>>

The Pokémon species that must be in the players party in order for the evolving Pokémon species to evolve into this Pokémon species.

party_type: Option<NamedApiResource<Type>>

The player must have a Pokémon of this type in their party during the evolution trigger event in order for the evolving Pokémon species to evolve into this Pokémon species.

relative_physical_stats: Option<i64>

The required relation between the Pokémon’s Attack and Defense stats. 1 means Attack > Defense. 0 means Attack = Defense. -1 means Attack < Defense.

time_of_day: Option<String>

The required time of day. Day or night.

trade_species: Option<NamedApiResource<PokemonSpecies>>

Pokémon species for which this one must be traded.

turn_upside_down: Option<bool>

Whether or not the 3DS needs to be turned upside-down as this Pokémon levels up.