pub struct VersionGroup {
pub id: i64,
pub name: String,
pub order: i64,
pub generation: NamedApiResource<Generation>,
pub move_learn_methods: Vec<NamedApiResource<MoveLearnMethod>>,
pub pokedexes: Vec<NamedApiResource<Pokedex>>,
pub regions: Vec<NamedApiResource<Region>>,
pub versions: Vec<NamedApiResource<Version>>,
}Expand description
Fields
id: i64The identifier for this resource.
name: StringThe name for this resource.
order: i64Order for sorting. Almost by date of release, except similar versions are grouped together.
generation: NamedApiResource<Generation>The generation this version was introduced in.
move_learn_methods: Vec<NamedApiResource<MoveLearnMethod>>A list of methods in which Pokémon can learn moves in this version group.
pokedexes: Vec<NamedApiResource<Pokedex>>A list of Pokédexes introduces in this version group.
regions: Vec<NamedApiResource<Region>>A list of regions that can be visited in this version group.
versions: Vec<NamedApiResource<Version>>The versions this version group owns.