pub struct ContestComboSets {
pub normal: Option<ContestComboDetail>,
pub super_: Option<ContestComboDetail>,
}Expand description
Fields
normal: Option<ContestComboDetail>A detail of moves this move can be used before or after, granting additional appeal points in contests.
super_: Option<ContestComboDetail>A detail of moves this move can be used before or after, granting additional appeal points in super contests.