pub struct MoveCategory {
pub id: Option<i64>,
pub name: Option<String>,
pub moves: Option<Vec<NamedApiResource<Move>>>,
pub descriptions: Option<Vec<Description>>,
}Expand description
Fields
id: Option<i64>The identifier for this resource.
name: Option<String>The name for this resource.
moves: Option<Vec<NamedApiResource<Move>>>A list of moves that fall into this category.
descriptions: Option<Vec<Description>>The description of this resource listed in different languages.