pub struct MoveStatAffectSets {
pub increase: Vec<MoveStatAffect>,
pub decrease: Vec<MoveStatAffect>,
}Expand description
Fields
increase: Vec<MoveStatAffect>A list of moves and how they change the referenced stat.
decrease: Vec<MoveStatAffect>A list of moves and how they change the referenced stat.