Module stat

Module stat 

Stats determine certain aspects of battles. Each Pokémon has a value for each stat which grows as they gain levels and can be altered momentarily by effects in battles.

Functions

get_all_entries
Returns all entries from the given resource.
get_by_id
Returns the resource, using its id.
get_by_name
Returns the resource, using its name.
get_page
Returns the default page regarding the resource.
get_page_with_param
Returns the page targeted by the parameters.