Encounter condition values are the various states that an encounter condition can have, i.e., time of day can be either day or night.
Functions
- get_
all_ entries - Returns all entries from the given resource.
- get_
by_ id - Returns the resource, using its id.
- get_
by_ name - Returns the resource, using its name.
- get_
page - Returns the default page regarding the resource.
- get_
page_ with_ param - Returns the page targeted by the parameters.