pub struct PokemonSpecies {Show 27 fields
pub id: Option<i64>,
pub name: Option<String>,
pub order: Option<i64>,
pub gender_rate: Option<i64>,
pub capture_rate: Option<i64>,
pub base_hapiness: Option<i64>,
pub is_baby: Option<bool>,
pub is_legendary: Option<bool>,
pub is_mythical: Option<bool>,
pub hatch_counter: Option<i64>,
pub has_gender_differences: Option<bool>,
pub forms_switchable: Option<bool>,
pub growth_rate: Option<NamedApiResource<GrowthRate>>,
pub pokemon_numbers: Option<Vec<PokemonSpeciesDexEntry>>,
pub egg_groups: Option<Vec<NamedApiResource<EggGroup>>>,
pub color: Option<NamedApiResource<PokemonColor>>,
pub shape: Option<NamedApiResource<PokemonShape>>,
pub evolves_from_species: Option<NamedApiResource<PokemonSpecies>>,
pub evolution_chain: Option<ApiResource>,
pub habitat: Option<NamedApiResource<PokemonHabitat>>,
pub generation: Option<NamedApiResource<Generation>>,
pub names: Option<Vec<Name>>,
pub pal_park_encounters: Option<Vec<PalParkEncounterArea>>,
pub flavor_text_entries: Option<Vec<FlavorText>>,
pub form_descriptions: Option<Vec<Description>>,
pub genera: Option<Vec<Genus>>,
pub varieties: Option<Vec<PokemonSpeciesVariety>>,
}Expand description
Fields
id: Option<i64>The identifier for this resource.
name: Option<String>The name for this resource.
order: Option<i64>The order in which species should be sorted. Based on National Dex order, except families are grouped together and sorted by stage.
gender_rate: Option<i64>The chance of this Pokémon being female, in eighths; or -1 for genderless.
capture_rate: Option<i64>The base capture rate; up to 255. The higher the number, the easier the catch.
base_hapiness: Option<i64>The happiness when caught by a normal Pokéball; up to 255. The higher the number, the happier the Pokémon.
is_baby: Option<bool>Whether or not this is a baby Pokémon.
is_legendary: Option<bool>Whether or not this is a legendary Pokémon.
is_mythical: Option<bool>Whether or not this is a mythical Pokémon.
hatch_counter: Option<i64>Initial hatch counter: one must walk 255 × (hatch_counter + 1) steps before this Pokémon’s egg hatches, unless utilizing bonuses like Flame Body’s.
has_gender_differences: Option<bool>Whether or not this Pokémon has visual gender differences.
forms_switchable: Option<bool>Whether or not this Pokémon has multiple forms and can switch between them.
growth_rate: Option<NamedApiResource<GrowthRate>>The rate at which this Pokémon species gains levels.
pokemon_numbers: Option<Vec<PokemonSpeciesDexEntry>>A list of Pokedexes and the indexes reserved within them for this Pokémon species.
egg_groups: Option<Vec<NamedApiResource<EggGroup>>>A list of egg groups this Pokémon species is a member of.
color: Option<NamedApiResource<PokemonColor>>The color of this Pokémon for Pokédex search.
shape: Option<NamedApiResource<PokemonShape>>The shape of this Pokémon for Pokédex search.
evolves_from_species: Option<NamedApiResource<PokemonSpecies>>The Pokémon species that evolves into this Pokemon_species.
evolution_chain: Option<ApiResource>The evolution chain this Pokémon species is a member of.
habitat: Option<NamedApiResource<PokemonHabitat>>The habitat this Pokémon species can be encountered in.
generation: Option<NamedApiResource<Generation>>The generation this Pokémon species was introduced in.
names: Option<Vec<Name>>The name of this resource listed in different languages.
pal_park_encounters: Option<Vec<PalParkEncounterArea>>A list of encounters that can be had with this Pokémon species in pal park.
flavor_text_entries: Option<Vec<FlavorText>>A list of flavor text entries for this Pokémon species.
form_descriptions: Option<Vec<Description>>Descriptions of different forms Pokémon take on within the Pokémon species.
genera: Option<Vec<Genus>>The genus of this Pokémon species listed in multiple languages.
varieties: Option<Vec<PokemonSpeciesVariety>>A list of the Pokémon that exist within this Pokémon species.