Stats determine certain aspects of battles. Each Pokémon has a value for each stat which grows as they gain levels and can be altered momentarily by effects in battles.
Functions
- get_
all_ entries - Returns all entries from the given resource.
- get_
by_ id - Returns the resource, using its id.
- get_
by_ name - Returns the resource, using its name.
- get_
page - Returns the default page regarding the resource.
- get_
page_ with_ param - Returns the page targeted by the parameters.